
#include<stdio.h>
#include<string.h>
#include<unistd.h>
#include<sys/socket.h>
#include<sys/time.h>
#include<netinet/in_systm.h>
#include<netinet/in.h>
#include<netinet/ip.h>
#include<netinet/ip_icmp.h>
#include<arpa/inet.h>

#include<sys/stat.h> 
#include<sys/un.h>

#include"sitar.h"
#include"sitar_scan.h"
#include"sitar_com.h"
#include<almemsys/almemsys.h>
#include"jpreturn.h"



/*--------------- MAKE ICMP8 PACKET --------------*/
int make_icmp8_packet(struct icmp *icmp, int len, int n, int id)
{
memset((char *) icmp, 0, len);
gettimeofday((struct timeval *) (icmp->icmp_data), (struct timezone *) 0);

icmp->icmp_type = ICMP_ECHO;
icmp->icmp_code = 0;
icmp->icmp_id = htons(id);
icmp->icmp_seq = htons(n);
icmp->icmp_cksum =0;
icmp->icmp_cksum = checksum((u_short *) icmp, len);

return 0;
}








